@@ -1,8 +1,8 @@
 library(easyVerification)
 context('Conversion to probabilities')
 xxx <- array(1:12, c(1,3,4))
-xx <- array(1:12, c(3,4))
-x <- 1:12
+xx <- t(array(1:15, c(3, 5)))
+x <- 1:15
 xna <- x
 xna[3] <- NA
 xxna <- xx
@@ -31,3 +31,11 @@ test_that("missing value treatment", {
   expect_true(all(is.na(convert2prob(xna, prob=0.5)[,2]) == is.na(xna)))
   expect_true(all(is.na(convert2prob(xxna, prob=0.5)[,2]) == apply(is.na(xxna), 1, any)))
 })
+
+test_that("out-of-sample percentile", {
+  expect_equal(convert2prob(x, threshold=1), convert2prob(x, threshold=1, ref.ind = indRef(nfcst=length(x), type='crossval')))
+  expect_equal(convert2prob(x), convert2prob(x, ref.ind = indRef(nfcst=length(x), type='block')))
+  expect_equal(convert2prob(x, prob=1:2/3), convert2prob(x, prob=1:2/3, ref.ind=indRef(nfcst=length(x), type='block')))
+  expect_equal(convert2prob(x, prob=1:2/3), convert2prob(x, prob=1:2/3, ref.ind=indRef(nfcst=length(x), type='crossval')))
+  expect_false(all(convert2prob(xx, prob=1:2/3) == convert2prob(xx, prob=1:2/3, ref.ind=indRef(nfcst=nrow(xx), type='crossval'))))
+})
